
import Link from 'next/link';
import style from "./button.module.css"
interface ButtonProps extends React.HTMLAttributes<HTMLElement> {
  variant?: 'primary' | 'light' | 'dark';
  size?: 'sm' | 'md';
  loading?: boolean;
  disabled?: boolean;
  href?: string;
  children: React.ReactNode;
}

export default function Button({
  variant = 'primary',
  size = 'md',
  loading = false,
  disabled = false,
  href,
  children,
  ...rest
}: ButtonProps) {


  const classNames = `${style.btn} ${size === 'sm' ? style.sm : style.md}`
  return typeof href === 'string' ? (
    <Link href={href} className={classNames} {...rest}>
      {children}
      {loading && <Loader />}
    </Link>
  ) : (
    <button disabled={disabled} className={classNames} {...rest}>
      {children}
      {loading && <Loader />}
    </button>
  );
}

export function Loader() {
  return (
    <span className={style.loader}>
    </span>
  );
}
